@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, 2010 Free Software Foundation, Inc.
+ * Copyright (C) 2009, 2010, 2011 Free Software Foundation, Inc.
  *
  * Author: Simon Josefsson
  *
@@ -33,8 +33,8 @@
 #include <stdio.h>
 #include <stdarg.h>
 #include <stdlib.h>
+#include <string.h>
 
-#include <gcrypt.h>
 #include <gnutls/gnutls.h>
 #include <gnutls/x509.h>
 
@@ -273,19 +273,19 @@ main (void)
 
       ret = gnutls_x509_privkey_init (&key);
       if (ret < 0)
-	return 1;
+        return 1;
 
       tmp.data = (char *) keys[i].pkcs12key;
       tmp.size = strlen (tmp.data);
 
       ret = gnutls_x509_privkey_import_pkcs8 (key, &tmp,
-					      GNUTLS_X509_FMT_PEM,
-					      keys[i].password, 0);
+                                              GNUTLS_X509_FMT_PEM,
+                                              keys[i].password, 0);
       if (ret != keys[i].expected_result)
-	{
-	  printf ("fail[%d]: %d: %s\n", (int) i, ret, gnutls_strerror (ret));
-	  return 1;
-	}
+        {
+          printf ("fail[%d]: %d: %s\n", (int) i, ret, gnutls_strerror (ret));
+          return 1;
+        }
 
       gnutls_x509_privkey_deinit (key);
     }
